.. _API reference:

=============
API reference
=============

.. contents::
   :local:

.. _api recipes:

Property recipes
----------------

.. autosummary::
   :template: autosummary/mytemplate.rst
   :toctree: .

   asr.asr
   asr.bader
   asr.bandstructure
   asr.berry
   asr.borncharges
   asr.bse
   asr.chc
   asr.convex_hull
   asr.defectformation
   asr.deformationpotentials
   asr.dimensionality
   asr.dos
   asr.emasses
   asr.exchange
   asr.fere
   asr.fermisurface
   asr.formalpolarization
   asr.gs
   asr.gw
   asr.hse
   asr.infraredpolarizability
   asr.magnetic_anisotropy
   asr.magstate
   asr.pdos
   asr.phonons
   asr.phonopy
   asr.piezoelectrictensor
   asr.plasmafrequency
   asr.polarizability
   asr.projected_bandstructure
   asr.push
   asr.raman
   asr.relax
   asr.setinfo
   asr.stiffness
   asr.structureinfo
   asr.workflow

.. _api setup recipes:

Setup recipes
-------------

.. autosummary::
   :template: autosummary/mytemplate.rst
   :toctree: .

   asr.setup.decorate
   asr.setup.defects
   asr.setup.displacements
   asr.setup.magnetize
   asr.setup.materials
   asr.setup.params
   asr.setup.scanparams
   asr.setup.strains
   asr.setup.symmetrize

.. _api database:

Database sub-package
--------------------

.. autosummary::
   :template: autosummary/mytemplate.rst
   :toctree: .

   asr.database.app
   asr.database.browser
   asr.database.check
   asr.database.clonetree
   asr.database.duplicates
   asr.database.fromtree
   asr.database.key_descriptions
   asr.database.material_fingerprint
   asr.database.merge
   asr.database.rmsd
   asr.database.totree

.. _api core:

Core sub-package
----------------

.. autosummary::
   :template: autosummary/mytemplate.rst
   :toctree: .

   asr.core.cli
   asr.core.command
   asr.core.fix_old_files
   asr.core.material
   asr.core.results
   asr.core.types
   asr.core.utils

.. _api test:

Test sub-package
----------------

.. autosummary::
   :template: autosummary/mytemplate.rst
   :toctree: .

   asr.test.acceptance.test_borncharges
   asr.test.acceptance.test_piezoelectrictensor
   asr.test.acceptance.test_relax
   asr.test.conftest
   asr.test.fixtures
   asr.test.materials
   asr.test.mocks.gpaw.berryphase
   asr.test.mocks.gpaw.calculator
   asr.test.mocks.gpaw.hybrids.eigenvalues
   asr.test.mocks.gpaw.kpt_descriptor
   asr.test.mocks.gpaw.mpi
   asr.test.mocks.gpaw.occupations
   asr.test.mocks.gpaw.response.bse
   asr.test.mocks.gpaw.response.df
   asr.test.mocks.gpaw.response.g0w0
   asr.test.mocks.gpaw.spinorbit
   asr.test.mocks.gpaw.symmetry
   asr.test.mocks.gpaw.utilities.dos
   asr.test.mocks.gpaw.utilities.ibz2bz
   asr.test.mocks.gpaw.utilities.progressbar
   asr.test.mocks.gpaw.xc.exx
   asr.test.mocks.gpaw.xc.tools
   asr.test.test_bandstructure
   asr.test.test_berry
   asr.test.test_borncharges
   asr.test.test_bse
   asr.test.test_cli
   asr.test.test_convex_hull
   asr.test.test_core
   asr.test.test_core_material
   asr.test.test_core_results
   asr.test.test_database_duplicates
   asr.test.test_database_fromtree
   asr.test.test_database_rmsd
   asr.test.test_database_totree
   asr.test.test_dimensionality
   asr.test.test_emasses
   asr.test.test_fixtures
   asr.test.test_formalpolarization
   asr.test.test_gs
   asr.test.test_gw
   asr.test.test_hse
   asr.test.test_pdos
   asr.test.test_phonons
   asr.test.test_phonopy
   asr.test.test_piezoelectrictensor
   asr.test.test_plasmafrequency
   asr.test.test_polarizability
   asr.test.test_projected_bandstructure
   asr.test.test_raman
   asr.test.test_recipes
   asr.test.test_relax
   asr.test.test_setinfo
   asr.test.test_setup_decorate
   asr.test.test_setup_displacements
   asr.test.test_setup_magnetize
   asr.test.test_setup_materials
   asr.test.test_setup_params
   asr.test.test_setup_scanparams
   asr.test.test_setup_strains
   asr.test.test_setup_symmetrize
   asr.test.test_stiffness
